face: Implementing new "isOnDemand" flag

This flags replaces isPermanent flag in datagram faces, but with the
reversed logic (isPermanent = !isOnDemand)

Change-Id: I37ba604e5f105ca95a79a08b8cfc3d640df8b412
Refs: #1376
diff --git a/daemon/face/udp-channel.hpp b/daemon/face/udp-channel.hpp
index 26c6cae..0243dd6 100644
--- a/daemon/face/udp-channel.hpp
+++ b/daemon/face/udp-channel.hpp
@@ -96,7 +96,7 @@
   shared_ptr<UdpFace>
   createFace(const shared_ptr<boost::asio::ip::udp::socket>& socket,
              const FaceCreatedCallback& onFaceCreated,
-             bool isPermanent);
+             bool isOnDemand);
   void
   afterFaceFailed(udp::Endpoint& endpoint);
 
@@ -152,7 +152,7 @@
   bool m_isListening;
   
   /**
    * \brief every time m_idleFaceTimeout expires all the idle (and not permanent)
    *        faces will be removed
    */
   time::seconds m_idleFaceTimeout;
@@ -152,7 +152,7 @@
   
   /**
-   * \brief every time m_idleFaceTimeout expires all the idle (and not permanent)
+   * \brief every time m_idleFaceTimeout expires all the idle (and on-demand)
    *        faces will be removed
    */